@@ -1,18 +1,18 @@
-#' Extract posterior sample of the pointwise log-likelihood from a varstan object.
+#' Extract posterior sample of the point wise log-likelihood from a `varstan` object.
 #'
-#' Convenience function for extracting the pointwise log-likelihood
+#' Convenience function for extracting the point wise log-likelihood
 #' matrix or array from a fitted Stan model.
 #'
-#' @param object A varstan object of the time series fitted model.
-#' @param permuted A logical scalar indicating whether the draws after
+#' @param object a `varstan` object of the time series fitted model.
+#' @param permuted a logical scalar indicating whether the draws after
 #' the \code{warmup} period in each chain should be permuted and merged.
 #' If FALSE, the original order is kept. For each \code{stanfit} object,
 #' the permutation is fixed (i.e., extracting samples a second time
 #' will give the same sequence of iterations).
-#' @param ... additional values need in log_lik methods
+#' @param ... additional values need in `log_lik` methods.
 #'
 #' @return
-#' Usually, an S x N matrix containing the pointwise log-likelihood
+#' Usually, an S x N matrix containing the point wise log-likelihood
 #' samples, where S is the number of samples and N is the number
 #' of observations in the data. If \code{permuted} is \code{FALSE},
 #' an S x N x R array is returned, where R is the number of fitted
@@ -42,7 +42,6 @@
 #' @examples
 #'
 #' \donttest{
-#'  library(astsa)
 #'  model = Sarima(birth,order = c(0,1,2),seasonal = c(1,1,1))
 #'  fit1 = varstan(model,iter = 500,chains = 1)
 #'
@@ -50,22 +49,23 @@
 #'  log1
 #' }
 #'
-log_lik.varstan = function(object,permuted = TRUE,...){
+log_lik.varstan = function(object, permuted = TRUE, ...){
+
   if(!is.varstan(object))
     stop("The current object is not varstan class")
 
-  log_lik = loo::extract_log_lik(object$stanfit,merge_chains = permuted)
+  log_lik = loo::extract_log_lik(object$stanfit, merge_chains = permuted)
   return(log_lik)
 }
-#' Extract posterior sample of the accumulated log-likelihood from a varstan object
+#' Extract posterior sample of the accumulated log-likelihood from a `varstan` object
 #'
 #' Convenience function for extracting the posterior sample of the accumulated
-#' log-likelihood array from a fitted varstan object.
+#' log-likelihood array from a fitted `varstan` object.
 #'
-#' @param object A varstan object of the time series fitted model.
-#' @param permuted A logical scalar indicating whether the draws after
-#' the warmup period in each chain should be permuted and merged.
-#' If FALSE, the original order is kept. For each stanfit object,
+#' @param object a `varstan` object of the time series fitted model.
+#' @param permuted a logical scalar indicating whether the draws after
+#' the `warmup`` period in each chain should be permuted and merged.
+#' If `FALSE`, the original order is kept. For each `stanfit` object,
 #' the permutation is fixed (i.e., extracting samples a second time
 #' will give the same sequence of iterations).
 #'
@@ -89,7 +89,6 @@ log_lik.varstan = function(object,permuted = TRUE,...){
 #'
 #' @examples
 #' \donttest{
-#'  library(astsa)
 #'  model = Sarima(birth,order = c(0,1,2),seasonal = c(1,1,1))
 #'  fit1 = varstan(model,iter = 500,chains = 1)
 #'
@@ -97,11 +96,14 @@ log_lik.varstan = function(object,permuted = TRUE,...){
 #'  log1
 #' }
 #'
-loglik = function(object,permuted = TRUE){
+loglik = function(object, permuted = TRUE){
+
   if(!is.varstan(object))
     stop("The current object is not varstan class")
 
-  loglik = data.frame(extract_stan(object = object,pars = "loglik",permuted = permuted))
+  loglik = data.frame(extract_stan(object = object,
+                                   pars = "loglik",
+                                   permuted = permuted))
 
   if(permuted)
     loglik = as.numeric(loglik$loglik)
@@ -113,25 +115,23 @@ loglik = function(object,permuted = TRUE){
 }
 #' Leave-one-out cross-validation
 #'
-#' The \code{loo} method for varstan objects. Computes approximate
+#' The \code{loo} method for `varstan` objects. Computes approximate
 #' leave-one-out cross-validation using Pareto smoothed importance
 #' sampling (PSIS-LOO CV).
 #'
 #' @aliases loo
 #'
-#' @param x A varstan object
+#' @param x A `varstan` object
 #' @param ... additional values need in loo methods
 #'
 #' @return an object from the loo class with the results of the Pareto-Smooth
 #' Importance Sampling, leave one out cross validation for model selection.
 #'
-#' @seealso
-#'  * The **loo** package [vignettes](https://mc-stan.org/loo/articles/index.html)
-#'    for demonstrations.
-#'  * [psis()] for the underlying Pareto Smoothed Importance Sampling (PSIS)
-#'    procedure used in the LOO-CV approximation.
-#'  * [pareto-k-diagnostic] for convenience functions for looking at diagnostics.
-#'  * [loo_compare()] for model comparison.
+#' @seealso The \pkg{loo} package [vignettes](https://mc-stan.org/loo/articles/index.html)
+#' for demonstrations. \code{psis()} for the underlying Pareto Smoothed Importance
+#' Sampling (PSIS) procedure used in the LOO-CV approximation. \code{pareto-k-diagnostic}
+#' for convenience functions for looking at diagnostics.\code{loo_compare()} for
+#' model comparison.
 #'
 #' @references
 #' Vehtari, A., Gelman, A., & Gabry J. (2016). Practical Bayesian model
@@ -151,10 +151,8 @@ loglik = function(object,permuted = TRUE){
 #' @export loo
 #' @export
 #'
-#'
 #' @examples
 #' \donttest{
-#' library(astsa)
 #' model = Sarima(birth,order = c(0,1,2),seasonal = c(1,1,1))
 #' fit1 = varstan(model,iter = 500,chains = 1)
 #'
@@ -162,7 +160,7 @@ loglik = function(object,permuted = TRUE){
 #' loo1
 #' }
 #'
-loo.varstan = function(x,...){
+loo.varstan = function(x, ...){
   if (!is.varstan(x))
     stop("The current object is not a varstan class")
 
@@ -205,7 +203,6 @@ loo.varstan = function(x,...){
 #'
 #' @examples
 #' \donttest{
-#'  library(astsa)
 #'  model = Sarima(birth,order = c(0,1,2),seasonal = c(1,1,1))
 #'  fit1 = varstan(model,iter = 500,chains = 1)
 #'
@@ -219,15 +216,15 @@ waic.varstan = function(x,...){
 
   return(loo::waic(log_lik.varstan(x)) )
 }
-#' Computes posterior sample of the pointwise AIC method from a varstan object
+#' Computes posterior sample of the point wise AIC method from a `varstan` object
 #'
-#' Convenience function for computing the pointwise Akaike Information Criteria
-#' method from a varstan object.
+#' Convenience function for computing the point wise Akaike Information Criteria
+#' method from a `varstan` object.
 #'
-#' @param x A varstan object of the time series fitted model.
+#' @param x A `varstan` object of the time series fitted model.
 #'
 #' @return A numeric array  of size R, containing the posterior samples of the AICc
-#' for a varstan object, where R is the number of iterations. If multiple chains are
+#' for a `varstan` object, where R is the number of iterations. If multiple chains are
 #' fitted, then the array is of length M*R, where M is the number of chains
 #'
 #' @export
@@ -236,7 +233,6 @@ waic.varstan = function(x,...){
 #'
 #' @examples
 #' \donttest{
-#'  library(astsa)
 #'  model = Sarima(birth,order = c(0,1,2),seasonal = c(1,1,1))
 #'  fit1 = varstan(model,iter = 500,chains = 1)
 #'
@@ -269,7 +265,6 @@ aic = function(x){
 #' @examples
 #'
 #' \donttest{
-#'  library(astsa)
 #'  model = Sarima(birth,order = c(0,1,2),seasonal = c(1,1,1))
 #'  fit1 = varstan(model,iter = 500,chains = 1)
 #'
@@ -285,16 +280,17 @@ bic = function(x){
   bic = 2*k*log(n) - 2*loglik(x)
   return(bic)
 }
-#' Computes posterior sample of the pointwise corrected AIC method from a varstan object
+#' Computes posterior sample of the point wise corrected AIC method from a `varstan` object
 #'
-#' Convenience function for computing the pointwise corrected  Akaike Information Criteria
-#' method from a varstan object.
+#' Convenience function for computing the point wise corrected Akaike Information
+#' Criterion method from a `varstan` object.
 #'
-#' @param x A varstan object of the time series fitted model.
+#' @param x a `varstan` object of the time series fitted model.
 #'
-#' @return A numeric array  of size R, containing the posterior samples of the AICc
-#' for a varstan object, where R is the number of iterations. If multiple chains are
-#' fitted, then the array is of length M*R, where m is the number of chains
+#' @return A numeric array  of size `R`, containing the posterior samples of the
+#' AICc for a `varstan` object. where `R` is the number of iterations. If multiple
+#' chains are fitted, then the array is of length `m*R`, where `m` is the number of
+#' chains.
 #'
 #' @export
 #'
@@ -303,7 +299,6 @@ bic = function(x){
 #' @examples
 #'
 #' \donttest{
-#'  library(astsa)
 #'  model = Sarima(birth,order = c(0,1,2),seasonal = c(1,1,1))
 #'  fit1 = varstan(model,iter = 500,chains = 1)
 #'
